@@ -12,37 +12,34 @@
 
 using namespace KNSCore;
 
-class DownloadJob::Private
+class KNSCore::DownloadJobPrivate
 {
 public:
-    Private() {}
+    DownloadJobPrivate() = default;
     QUrl source;
     QUrl destination;
 };
 
-DownloadJob::DownloadJob(const QUrl& source, const QUrl& destination, int permissions, JobFlags flags, QObject* parent)
+DownloadJob::DownloadJob(const QUrl &source, const QUrl &destination, int permissions, JobFlags flags, QObject *parent)
     : FileCopyJob(source, destination, permissions, flags, parent)
-    , d(new Private)
+    , d(new DownloadJobPrivate)
 {
     d->source = source;
     d->destination = destination;
 }
 
-DownloadJob::DownloadJob(QObject* parent)
+DownloadJob::DownloadJob(QObject *parent)
     : FileCopyJob(parent)
-    , d(new Private)
+    , d(new DownloadJobPrivate)
 {
 }
 
-DownloadJob::~DownloadJob()
-{
-    delete d;
-}
+DownloadJob::~DownloadJob() = default;
 
 void DownloadJob::start()
 {
     qCDebug(KNEWSTUFFCORE) << Q_FUNC_INFO;
-    HTTPWorker* worker = new HTTPWorker(d->source, d->destination, HTTPWorker::DownloadJob, this);
+    HTTPWorker *worker = new HTTPWorker(d->source, d->destination, HTTPWorker::DownloadJob, this);
     connect(worker, &HTTPWorker::completed, this, &DownloadJob::handleWorkerCompleted);
     connect(worker, &HTTPWorker::error, this, &DownloadJob::handleWorkerError);
     worker->startRequest();
@@ -53,8 +50,10 @@ void DownloadJob::handleWorkerCompleted()
     emitResult();
 }
 
-void KNSCore::DownloadJob::handleWorkerError(const QString& error)
+void KNSCore::DownloadJob::handleWorkerError(const QString &error)
 {
     setError(KJob::UserDefinedError);
     setErrorText(error);
 }
+
+#include "moc_downloadjob.cpp"
